@@ -8,8 +8,9 @@ test_that("Kronecker products (I x A)B with I=diag(N)", {
   A = matrix(rnorm(dims['m'] * dims['n']), ncol=dims['n'])
   B = matrix(rnorm( dims['N'] * dims['n'] * dims['p']), ncol=dims['p'])
       
-  expect_identical(
+  expect_equal(
     kronecker(diag(dims['N']), A) %*% B,
-    .Call(`_telefit_r_dgeikmm`, dims['N'], A, B)
+    .Call(`_telefit_r_dgeikmm`, dims['N'], A, B),
+    tolerance = 1e-3
   )
 })
